ged4py package
==============

Subpackages
-----------

.. toctree::

    ged4py.detail

Submodules
----------

ged4py\.codecs module
---------------------

.. automodule:: ged4py.codecs
    :members:
    :undoc-members:
    :show-inheritance:

ged4py\.model module
--------------------

.. automodule:: ged4py.model
    :members:
    :undoc-members:
    :show-inheritance:

ged4py\.parser module
---------------------

.. automodule:: ged4py.parser
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ged4py
    :members:
    :undoc-members:
    :show-inheritance:
